/// <reference types="node" />
import { EventEmitter } from 'events';
import { IDatabase, Interfaces } from "./Types";
import { PoolConnection } from 'mysql';
/**
 * MYSQL interface that implements IDatabase
 */
export declare class MySQL extends EventEmitter implements IDatabase {
    private readonly m_db;
    private m_tableOptions;
    /**
     * Creates a new instance of the class
     * @param host
     * @param port
     * @param user
     * @param password
     * @param database
     * @param connectionLimit
     */
    constructor(host: string, port: number, user: string, password: string, database: string, connectionLimit?: number);
    get hashType(): string;
    get blobType(): string;
    get uint32Type(): string;
    get uint64Type(): string;
    get tableOptions(): string | undefined;
    set tableOptions(value: string | undefined);
    get type(): Interfaces.DBType;
    on(event: 'error', listener: (error: Error) => void): this;
    on(event: 'acquire', listener: (connection: PoolConnection) => void): this;
    on(event: 'connection', listener: (connection: PoolConnection) => void): this;
    on(event: 'enqueue', listener: () => void): this;
    on(event: 'release', listener: (connection: PoolConnection) => void): this;
    on(event: 'ready', listener: () => void): this;
    createTable(name: string, fields: Interfaces.ITableColumn[], primaryKey: string[], tableOptions?: string): Promise<void>;
    prepareCreateTable(name: string, fields: Interfaces.ITableColumn[], primaryKey: string[], tableOptions?: string): {
        table: string;
        indexes: string[];
    };
    close(): Promise<void>;
    query(query: string, values?: any[]): Promise<Interfaces.IQueryResult>;
    transaction(queries: Interfaces.IBulkQuery[]): Promise<void>;
    prepareMultiInsert(query: string, values?: Interfaces.IValueArray): string;
    private connection;
}
