/// <reference types="node" />
import { EventEmitter } from 'events';
import { PoolClient } from 'pg';
import { IDatabase, Interfaces } from "./Types";
export declare class Postgres extends EventEmitter implements IDatabase {
    private readonly m_pool;
    private m_tableOptions;
    /**
     * Creates a new instance of the class
     * @param host
     * @param port
     * @param username
     * @param password
     * @param database
     */
    constructor(host: string, port: number, username: string, password: string, database: string);
    get hashType(): string;
    get blobType(): string;
    get uint32Type(): string;
    get uint64Type(): string;
    get tableOptions(): string | undefined;
    set tableOptions(value: string | undefined);
    get type(): Interfaces.DBType;
    on(event: 'connect', listener: (client: PoolClient) => void): this;
    on(event: 'acquire', listener: (client: PoolClient) => void): this;
    on(event: 'remove', listener: (client: PoolClient) => void): this;
    on(event: 'error', listener: (error: Error) => void): this;
    on(event: 'ready', listener: () => void): this;
    close(): Promise<void>;
    createTable(name: string, fields: Interfaces.ITableColumn[], primaryKey: string[], tableOptions?: string): Promise<void>;
    prepareCreateTable(name: string, fields: Interfaces.ITableColumn[], primaryKey: string[], tableOptions?: string): {
        table: string;
        indexes: string[];
    };
    query(query: string, values?: any[], openClient?: PoolClient): Promise<Interfaces.IQueryResult>;
    transaction(queries: Interfaces.IBulkQuery[]): Promise<void>;
    prepareMultiInsert(query: string, values?: Interfaces.IValueArray): string;
}
