/// <reference types="node" />
import { EventEmitter } from 'events';
import { IDatabase, Interfaces } from "./Types";
import { Database } from 'sqlite3';
export declare class SQLite extends EventEmitter implements IDatabase {
    private readonly m_db;
    private m_tableOptions;
    /**
     * Creates a new instance of the class
     * @param filepath
     * @param mode
     */
    constructor(filepath: string, mode?: number);
    get hashType(): string;
    get blobType(): string;
    get uint32Type(): string;
    get uint64Type(): string;
    get tableOptions(): string | undefined;
    set tableOptions(value: string | undefined);
    get type(): Interfaces.DBType;
    on(event: 'error', listener: (error: Error) => void): this;
    on(event: 'ready', listener: (filepath: string, mode: number) => void): this;
    createTable(name: string, fields: Interfaces.ITableColumn[], primaryKey: string[], tableOptions?: string): Promise<void>;
    prepareCreateTable(name: string, fields: Interfaces.ITableColumn[], primaryKey: string[], tableOptions?: string): {
        table: string;
        indexes: string[];
    };
    getPragma(option: string): Promise<any>;
    setPragma(option: string, value: boolean | number | string): Promise<void>;
    close(): Promise<void>;
    query(query: string, values?: any[]): Promise<Interfaces.IQueryResult>;
    connection(): Promise<Database>;
    transaction(queries: Interfaces.IBulkQuery[]): Promise<void>;
    prepareMultiInsert(query: string, values?: Interfaces.IValueArray): string;
}
