"use strict";
// Copyright (c) 2020 Brandon Lehmann
//
// Please see the included LICENSE file for more information.
Object.defineProperty(exports, "__esModule", { value: true });
exports.prepareCreateTable = exports.IDatabase = exports.Interfaces = void 0;
const util_1 = require("util");
var Interfaces;
(function (Interfaces) {
    /**
     * The database type
     */
    let DBType;
    (function (DBType) {
        DBType[DBType["MYSQL"] = 0] = "MYSQL";
        DBType[DBType["POSTGRES"] = 1] = "POSTGRES";
        DBType[DBType["SQLITE"] = 2] = "SQLITE";
    })(DBType = Interfaces.DBType || (Interfaces.DBType = {}));
    /**
     * Foreign key constraint action enum
     */
    let FKAction;
    (function (FKAction) {
        FKAction["RESTRICT"] = "RESTRICT";
        FKAction["CASCADE"] = "CASCADE";
        FKAction["NULL"] = "SET NULL";
        FKAction["DEFAULT"] = "SET DEFAULT";
        FKAction["NA"] = "NO ACTION";
    })(FKAction = Interfaces.FKAction || (Interfaces.FKAction = {}));
})(Interfaces = exports.Interfaces || (exports.Interfaces = {}));
/**
 * Abstract database class that all underlying database
 * classes must implement so that we have consistency in methods
 */
class IDatabase {
}
exports.IDatabase = IDatabase;
function prepareCreateTable(dbType, name, fields, primaryKey, tableOptions) {
    const l_fields = fields.map(col => util_1.format('%s %s %s %s', col.name, col.type, (!col.nullable) ? 'NOT NULL' : 'NULL', (typeof col.default !== 'undefined') ? 'DEFAULT ' + col.default : ''));
    const l_unique = fields.filter(elem => elem.unique === true)
        .map(col => util_1.format('CREATE UNIQUE INDEX IF NOT EXISTS %s_unique_%s ON %s (%s);', name, col.name, name, col.name));
    const constraint_fmt = ', CONSTRAINT %s_%s_fkey FOREIGN KEY (%s) REFERENCES %s (%s)';
    const l_constraints = [];
    for (const field of fields) {
        if (field.foreign) {
            let constraint = util_1.format(constraint_fmt, name, field.name, field.name, field.foreign.table, field.foreign.column);
            if (field.foreign.delete) {
                constraint += util_1.format(' ON DELETE %s', field.foreign.delete.toUpperCase());
            }
            if (field.foreign.update) {
                constraint += util_1.format(' ON UPDATE %s', field.foreign.update.toUpperCase());
            }
            l_constraints.push(constraint);
        }
    }
    let sql = util_1.format('CREATE TABLE %s %s (%s, PRIMARY KEY (%s)%s) %s;', (dbType !== Interfaces.DBType.MYSQL) ? 'IF NOT EXISTS' : '', name, l_fields.join(', '), primaryKey.join(','), l_constraints.join(','), tableOptions || '').trim();
    return {
        table: sql,
        indexes: l_unique
    };
}
exports.prepareCreateTable = prepareCreateTable;
